#
# spec file for package vido
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vido
Version:        2.3.0
Release:        1.17
Summary:        Online Video Downloader
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            https://github.com/bernardodsanderson/vido
Source:         https://github.com/bernardodsanderson/vido/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext-runtime >= 0.19.7
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.40.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(granite) >= 5.2.3
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libhandy-1)
Requires:       youtube-dl
Recommends:     %{name}-lang

%description
This tool downloads online videos from various sources including
archive.org and others.

%lang_package

%prep
%setup -q

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.github.bernardodsanderson.vido GTK Network FileTransfer
%find_lang com.github.bernardodsanderson.vido %{name}.lang
%fdupes %{buildroot}/%{_datadir}

# dirlist HiDPI icons (see: hicolor/index.theme)
touch $PWD/dir.lst
_dirlist=$PWD/dir.lst
pushd %{buildroot}
find ./ | while read _list; do
    echo $_list | grep '[0-9]\@[0-9]' || continue
    _path=$(echo $_list | sed 's/[^/]//')
    if ! ls ${_path%/*}; then
        grep -xqs "\%dir\ ${_path%/*}" $_dirlist || echo "%dir ${_path%/*}" >> $_dirlist
    fi
done
popd

%files -f dir.lst
%license LICENSE
%doc AUTHORS README.md
%{_bindir}/com.github.bernardodsanderson.vido
%{_datadir}/applications/com.github.bernardodsanderson.vido.desktop
%{_datadir}/icons/hicolor/*/apps/com.github.bernardodsanderson.vido.??g
%{_datadir}/metainfo/com.github.bernardodsanderson.vido.appdata.xml
%{_datadir}/glib-2.0/schemas/com.github.bernardodsanderson.vido.gschema.xml

%files lang -f %{name}.lang

%changelog
* Sun Feb 20 2022 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.3.0:
  * Update version in data
  * Update screenshots (#80)
  * Update version number
  * App release notes
  * MainWindow: Correctly set the app title (#79)
  * Update LINGUAS (#77)
  * Update LINGUAS (#78)
  * MainWindow: Add missing Hdy.init() (#76)
  * Create it.po (#74)
  * Create it.po (#65)
  * Update LINGUAS (#64)
  * l10n: Correctly setup the locales (#73)
  * Add notification when download done (#72)
  * Migrate from Travis CI to GitHub Actions (#71)
  * Less scope in Flatpak, fix folder selection, and fix merging
    into mkv (#70)
  * Rounded window corners and flat titlebar (#69)
* Fri Nov  5 2021 Alexei Podvalsky <avvissu@yandex.by>
- Update to 2.1.0:
  * Add new screenshots
  * Delete VIDO-normal.png
  * Delete VIDO-ready.png
  * Update README.md
  * Gitignore .flatpak-builder dir (#63)
  * Fix appdata parse error (#62)
  * Move Flatpak manifest to the source root (#61)
  * Add Flatpak support
  * Add stripe key #60
  * Fix POTFILES (#52)
  * Add a clear icon only when there are some text(s) in the
    entry (#51)
  * Set Node.js version to 10.17.0 to fix CI (#58)
  * Fix thick titlebar on GTK 3.22 or later (#50)
  * Use symbolic icon for 'edit-clear' icon (#49)
  * Save state and improve UI (#48)
  * Show download error details (#47)
* Mon Dec  9 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.1:
  * Update version
  * Add Travis CI file for automated tests (#46)
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrasing in descriptions.
* Thu Jul  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.3.0:
  * App refactoring (#43)
* Tue Jun 11 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.8:
  * Update version
  * Remove unneeded files (#42)
  * Fix sensitivity of download_button (#39)
  * Hopefully fix granite dependecy
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.7:
  * Add granite to build-depends
  * Version update and fix category
  * Merge pull request #32 from ryonakano/avoid-unexpected-window-size
* Mon Feb 18 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.4:
  * Merge pull request #27 from
    ryonakano/fix-infobutton-sensitivity
  * Merge pull request #31 from camellan/master
  * Make info_button insensitive if url_input has no text
  * Add license #26
  * Remove Granite dependency
- Add a new package with translations
* Thu Jan 17 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.2.2:
  * Update to Appdate for changelog
  * Fix audio download issue
  * Update README
* Sat Jan 12 2019 Alexei Podvalsky <avvissu@yandex.by>
- Initial package
